import type { TurboModule } from 'react-native';
import { TurboModuleRegistry, NativeModules, Platform } from 'react-native';
import { Double } from 'react-native/Libraries/Types/CodegenTypes';

export interface Spec extends TurboModule {
  isFileUploadSupported(): Promise<boolean>;
  shouldStartLoadWithLockIdentifier(
    shouldStart: boolean,
    lockIdentifier: Double
  ): void;
}

// 안전한 모듈 참조 구현
let nativeModule: Spec | null = null;

try {
  if (TurboModuleRegistry.getEnforcing) {
    nativeModule = TurboModuleRegistry.getEnforcing<Spec>('BPCWebViewModule');
  } else if (NativeModules.BPCWebViewModule) {
    nativeModule = NativeModules.BPCWebViewModule as Spec;
  }
} catch (error) {
  console.warn('BPCWebViewModule를 찾을 수 없습니다. 더미 구현을 사용합니다.');
}

// 모듈이 없는 경우 더미 구현 제공
const BPCWebViewModule: Spec = nativeModule || {
  isFileUploadSupported: async () => Platform.OS !== 'web',
  shouldStartLoadWithLockIdentifier: () => {},
};

export default BPCWebViewModule;
